@@ -18,7 +18,7 @@
 #ifndef CONTACT_H
 #define CONTACT_H
 
-#include <QImage>
+#include <QPixmap>
 #include <QStringList>
 class Contact
 {
@@ -27,7 +27,7 @@ public:
     ~Contact();
 
     bool Selected;
-    QImage* Thumbnail;
+    QPixmap* Thumbnail;
     int Id;
     QString Name;
     QString Number;
