@@ -33,9 +33,7 @@ public:
     void run();
 
 private:
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
-    bool IsContactValid(QContact* c, QStringList* numbers);
-#endif
+
 };
 
 #endif // CONTACTSLOADER_H
