@@ -48,79 +48,47 @@ ContactsWindow::ContactsWindow(QWidget *parent, Group* group) :
     connect(ui->txtCerca, SIGNAL(textChanged(QString)), this, SLOT(CercaSlot()));
     connect(ui->btnClear, SIGNAL(clicked()), this, SLOT(ClearSlot()));
     connect(ui->btnOK, SIGNAL(clicked()), this, SLOT(OkSlot()));
+
+    connect(ui->tblContacts, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(ContactDoubleClick(QModelIndex)));
+    m_DataModel = NULL;
 }
 
 ContactsWindow::~ContactsWindow()
 {
     delete ui;
+    if (m_DataModel){
+        delete m_DataModel;
+        m_DataModel = NULL;
+    }
 }
 
 void ContactsWindow::FillContactsList()
 {
-    m_Contacts = CommonStatic::ContactsCache;
-
-    connect(ui->tblContacts, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(ContactDoubleClicked(int, int)));
-    ui->tblContacts->setSortingEnabled(false);
-    ui->tblContacts->setColumnCount(4);
-    ui->tblContacts->setRowCount(m_Contacts.count());
-
-#ifdef Q_WS_MAEMO_5
-    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
-#endif
-
-    QPixmap* tImage = new QPixmap(":/images/contacts.png");
-    QPixmap* cImage = new QPixmap(tImage->scaled(48, 48, Qt::KeepAspectRatio));
-    delete tImage;
-    int i = 0;
-    int count = 0;
-    foreach (Contact* c, m_Contacts){
-        if (!m_Group->Contains(c->Number)){
-            AddContactToList(c, count, i, cImage);
-            count++;
-        }
-        i++;
+    if (m_DataModel){
+        delete m_DataModel;
+        m_DataModel = NULL;
     }
-    delete cImage;
 
-    ui->tblContacts->setRowCount(count);
-    ui->tblContacts->sortItems(2, Qt::AscendingOrder);
+    foreach(Contact* c, CommonStatic::ContactsCache){
+        if (!m_Group->Contains(c->Number))
+            m_Contacts.append(c);
+    }
+
+    m_DataModel = new ContactsDataModel(this, &m_Contacts);
+    m_DataModel->selectAll(false);
+    ui->tblContacts->setModel(m_DataModel);
+    ui->tblContacts->verticalHeader()->setDefaultSectionSize(60);
+    ui->tblContacts->verticalHeader()->setDefaultAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     ui->tblContacts->resizeColumnToContents(0);
     ui->tblContacts->resizeColumnToContents(1);
 
-    setWindowTitle(tr("Address book (%1)").arg(count));
+    setWindowTitle(tr("Address book (%1)").arg(m_Contacts.count()));
     resizeEvent(NULL);
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
 }
 
-void ContactsWindow::AddContactToList(Contact* c, int row, int index, QPixmap* defaultImage)
-{    
-    ui->tblContacts->setRowHeight(row, 60);
-    QCheckBox* chk = new QCheckBox(ui->tblContacts);
-    chk->setObjectName(QString("%1").arg(index));
-    chk->setStyleSheet("border-style: none;");
-    ui->tblContacts->setCellWidget(row, 0, chk);
-
-    QLabel* lbl = new QLabel(ui->tblContacts);
-    lbl->setAlignment(Qt::AlignCenter);
-    lbl->setMaximumWidth(48);
-    if (c->Thumbnail != NULL)
-        lbl->setPixmap(QPixmap::fromImage(*c->Thumbnail));
-    else
-        lbl->setPixmap(*defaultImage);
-    ui->tblContacts->setCellWidget(row, 1, lbl);
-
-    lbl = new QLabel(ui->tblContacts);
-    lbl->setText(c->Name);
-    ui->tblContacts->setCellWidget(row, 2, lbl);
-
-    QTableWidgetItem* item = new QTableWidgetItem(0);
-    item->setText(c->Number);
-    item->setTextAlignment(Qt::AlignVCenter | Qt::AlignRight);
-    ui->tblContacts->setItem(row, 3, item);
-}
-
 QList<Contact*> ContactsWindow::GetSelectedContacts()
 {
     return m_Selected;
@@ -153,30 +121,10 @@ void ContactsWindow::CercaSlot()
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
-    ui->txtCerca->setFocus();
-
-    int count = 0;
-    for (int i=0; i<ui->tblContacts->rowCount(); i++){
-        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
-        int index = chk->objectName().toInt();
-        Contact* c = m_Contacts.at(index);
-        if (c){
-            QLabel* lbl = (QLabel*)ui->tblContacts->cellWidget(i, 2);
-            if (lbl){
-                QString text = c->Name;
-                if (ui->txtCerca->text().isEmpty() || text.contains(ui->txtCerca->text(), Qt::CaseInsensitive)){
-                    if (!ui->txtCerca->text().isEmpty())
-                        text.replace(ui->txtCerca->text(), QString("<b>%1</b>").arg(ui->txtCerca->text()), Qt::CaseInsensitive);
-                    lbl->setText(text);
-                    ui->tblContacts->setRowHidden(i, false);
-                    count++;
-                }else
-                    ui->tblContacts->setRowHidden(i, true);
-            }
-        }
-    }
 
+    int count = m_DataModel->search(ui->tblContacts, ui->txtCerca->text());
     setWindowTitle(tr("Address book (%1)").arg(count));
+
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
@@ -191,23 +139,15 @@ void ContactsWindow::OkSlot()
 {
     m_Selected.clear();
 
-    for (int i=0; i<ui->tblContacts->rowCount(); i++){
-        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
-        if (chk && chk->isChecked()){
-            int index = chk->objectName().toInt();
-            Contact* c = m_Contacts.at(index);
-            m_Selected.append(c);
-        }
-    }
+    foreach (Contact* c, m_DataModel->getSelected())
+        m_Selected.append(c);
 
     accept();
 }
 
-void ContactsWindow::ContactDoubleClicked(int row, int)
+void ContactsWindow::ContactDoubleClick(QModelIndex index)
 {
-    QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(row, 0);
-    if (chk)
-        chk->setChecked(!chk->isChecked());
+    m_DataModel->toggleSelect(index);
 }
 
 void ContactsWindow::resizeEvent (QResizeEvent*)
