@@ -28,6 +28,7 @@
     #include "qtcontacts.h"
     using namespace QtMobility;
 #endif
+#include "contactsdatamodel.h"
 #include "contact.h"
 #include "group.h"
 
@@ -52,16 +53,16 @@ private:
 
     Group* m_Group;
     QTimer* m_Timer;
+    ContactsDataModel* m_DataModel;
     QList<Contact*> m_Contacts;
     QList<Contact*> m_Selected;
-    void AddContactToList(Contact* c, int row, int index, QPixmap* defaultImage);
 
 private slots:
     void TimerSlot();
     void CercaSlot();
     void ClearSlot();
     void OkSlot();
-    void ContactDoubleClicked(int row, int column);
+    void ContactDoubleClick(QModelIndex index);
 
 protected:
     void resizeEvent(QResizeEvent*);
