@@ -27,6 +27,13 @@ Group::Group()
     Id = 0;
 }
 
+Group::~Group()
+{
+    foreach(GroupContact* c, ContactsId)
+        delete c;
+    ContactsId.clear();
+}
+
 bool Group::IsValid()
 {
     return Id > 0;
