@@ -25,7 +25,7 @@
 #include "sendwindow.h"
 
 GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
-    QDialog(parent),
+    QMainWindow(parent),
     ui(new Ui::GroupActionsWindow)
 {
     ui->setupUi(this);
@@ -34,6 +34,7 @@ GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5NonComposited, true);
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
     setWindowTitle(m_Group->Name);
@@ -59,6 +60,7 @@ GroupActionsWindow::GroupActionsWindow(QWidget *parent, Group* group) :
 
     ui->tblContacts->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
+    m_Loop = NULL;
     m_DataModel = NULL;
     PopulateContactsTable();
     SelectAllContacts();
@@ -73,6 +75,9 @@ GroupActionsWindow::~GroupActionsWindow()
         delete m_DataModel;
         m_DataModel = NULL;
     }
+
+    if (m_Loop)
+        delete m_Loop;
 }
 
 
@@ -108,15 +113,21 @@ void GroupActionsWindow::AddContactSlot()
     ContactsWindow* frm = new ContactsWindow(this, m_Group);
     frm->Init();
     if (frm->exec() == QDialog::Accepted){
+        bool added = false;
         foreach (Contact* c, frm->GetSelectedContacts()){
             GroupContact* gc = new GroupContact();
             gc->Id = c->Id;
             gc->Number = c->Number;
             m_Group->ContactsId.append(gc);
+            added = true;
+        }
+
+        if (added){
+            m_Group->SaveToDb();
+            PopulateContactsTable();
+            SelectAllContacts();
+            resizeEvent(NULL);
         }
-        m_Group->SaveToDb();
-        PopulateContactsTable();
-        SelectAllContacts();
     }
     delete frm;
 }
@@ -173,11 +184,17 @@ void GroupActionsWindow::EditSlot()
     delete frm;
 }
 
-int GroupActionsWindow::exec()
+void GroupActionsWindow::show()
 {
-    show();
+    QMainWindow::show();
     resizeEvent(NULL);
-    return QDialog::exec();
+    m_Loop = new QEventLoop(this);
+    m_Loop->exec();
+}
+
+void GroupActionsWindow::closeEvent(QCloseEvent*)
+{
+    m_Loop->quit();
 }
 
 void GroupActionsWindow::resizeEvent (QResizeEvent*)
