@@ -18,8 +18,9 @@
 #ifndef GROUPACTIONSWINDOW_H
 #define GROUPACTIONSWINDOW_H
 
-#include <QDialog>
+#include <QMainWindow>
 #include <QMenu>
+#include <QEventLoop>
 #include "group.h"
 #include "contactsdatamodel.h"
 
@@ -27,7 +28,7 @@ namespace Ui {
     class GroupActionsWindow;
 }
 
-class GroupActionsWindow : public QDialog
+class GroupActionsWindow : public QMainWindow
 {
     Q_OBJECT
 
@@ -38,6 +39,7 @@ public:
 private:
     Ui::GroupActionsWindow *ui;
 
+    QEventLoop* m_Loop;
     Group* m_Group;
     QMenu* m_ContactMenu;
 
@@ -48,7 +50,8 @@ private:
     void SelectAllContacts(bool select=true);
 
 public slots:
-    int exec();
+    void show();
+    void closeEvent(QCloseEvent*);
 
 private slots:
     void AddContactSlot();
