@@ -189,6 +189,10 @@ void MainWindow::PopulateGroupsTable()
     ui->tblGroups->horizontalHeader()->hide();
     ui->tblGroups->horizontalHeader()->setStretchLastSection(true);
 
+    foreach (Group* g, m_Groups)
+        delete g;
+    m_Groups.clear();
+
     m_Groups = Group::GetGroupList();
 
     ui->tblGroups->setRowCount(m_Groups.count());
